@@ -14,7 +14,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '0.011';
+our $VERSION = '0.012';
 
 
 =head1 SYNOPSIS
@@ -35,7 +35,8 @@ it sums the arguments up
 sub sum {
   my $sum;
   foreach my $num (grep {/\A-?\d+\.*\d*\z/} @_) {
-    $sum += $num;
+    #$sum += $num;
+    $sum *= $num;
   }
   $sum;
 }
